@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
@@ -499,6 +499,13 @@ sub mapping {
       [os_darwin,
        [package => 'pkg-config']]],
 
+     [cpanmod => 'File::ExtAttr',
+      [like_debian,
+       [package => 'libattr1-dev']],
+      [linuxdistro => '~fedora',
+       [package => 'libattr-devel']],
+     ],
+
      [cpanmod => 'File::LibMagic',
       # XXX what about freebsd?
       [like_debian,
@@ -535,8 +542,8 @@ sub mapping {
       [os_freebsd,
        [package => 'gd']],
       [like_debian,
-       [linuxdistrocodename => ['precise'],
-	[package => 'libgd-noxpm-dev | libgd2-xpm-dev']],
+       [linuxdistrocodename => ['precise', 'wheezy'],
+	[package => 'libgd2-noxpm-dev | libgd2-xpm-dev']],
        [package => 'libgd-dev']],
       [os_darwin,
        [package => 'gd']]],
@@ -859,6 +866,8 @@ sub mapping {
       [os_freebsd,
        [package => 'v8']],
       # XXX what about debian?
+      [os_darwin,
+       [package => 'v8']], # but compilation errors (v8-5.0.71.33 <-> JavaScript-V8-0.07)
      ],
 
 #	# for some Judy-using modules (XXX which one?)
@@ -1029,6 +1038,15 @@ sub mapping {
        ],
        [package => 'libnanomsg-dev']]],
 
+     [cpanmod => 'Net::CDP',
+      [os_freebsd,
+       [package => 'libnet']], # but build failure with Net-CDP-0.09
+      [like_debian,
+       [package => 'libnet1-dev']],
+      [os_darwin,
+       [package => 'libnet']], # but build failure with Net-CDP-0.09
+     ],
+
      [cpanmod => 'Net::DBus',
       [os_freebsd,
        [package => ['dbus', 'pkgconf']]],
@@ -1350,6 +1368,7 @@ sub mapping {
       [like_debian,
        [package => 'libreadline6-dev']],
       # XXX what about freebsd?
+      # XXX no homebrew package for darwin (checked 2016-05-22)
      ],
 
      [cpanmod => 'Term::VTerm',
